@@ -4,7 +4,7 @@
 # Pod stripped from pm file by OODoc 2.01.
 package Dancer2::Plugin::LogReport;
 use vars '$VERSION';
-$VERSION = '1.08';
+$VERSION = '1.09';
 
 
 use warnings;
@@ -31,6 +31,8 @@ my %session_messages;
 # The default reasons that a message will be displayed to the end user
 my @default_reasons = qw/NOTICE WARNING MISTAKE ERROR FAULT ALERT FAILURE PANIC/;
 my $hide_real_message; # Used to hide the real message to the end user
+my $messages_variable = $_settings->{messages_key} || 'messages';
+
 
 # Dancer2 import
 on_plugin_import
@@ -64,6 +66,11 @@ on_plugin_import
         });
     }
 
+    $dsl->hook(after_layout_render => sub {
+        my $session = $_dsl->app->session;
+        $session->write($messages_variable => []);
+    });
+
     # Define which messages are saved to the session for later display
     # to the user. This can be configured in the config file, or we
     # choose some sensible defaults.
@@ -92,23 +99,23 @@ on_plugin_import
 
 sub process($$)
 {   my ($dsl, $coderef) = @_;
-    try { $coderef->() };
-
-    # Return true on success
-    if (my $exception = $@->wasFatal)
-    {   $exception->throw(is_fatal => 0);
-        return 0;
-    }
-    $@->reportAll;
-    1;
+    try { $coderef->() } hide => 'ALL';
+    my $success = $@->died ? 0 : 1;
+    $@->reportAll(is_fatal => 0);
+    $success;
 }
 
 register process => \&process;
 
 sub _message_add($)
 {   my $msg = shift;
-    return unless $session_messages{$msg->reason};
-    unless ($_dsl->app->request)
+
+    return
+        if ! $session_messages{$msg->reason}
+        ||   $msg->inClass('no_session');
+
+    my $app = $_dsl->app;
+    unless($app->request)
     {   # This happens for HTTP errors
         # XXX the session is not available in the DSL
         report 'ASSERT' => "Unable to write message to session: unable to write cookie";
@@ -121,8 +128,7 @@ sub _message_add($)
         $msg->reason($r);
     }
 
-    my $messages_variable = $_settings->{messages_key} || 'messages';
-    my $session           = $_dsl->app->session;
+    my $session           = $app->session;
     my $msgs              = $session->read($messages_variable);
     push @$msgs, $msg;
     $session->write($messages_variable => $msgs);
@@ -141,8 +147,9 @@ sub _error_handler($$$$)
 {   my ($disp, $options, $reason, $message) = @_;
 
     my $fatal_handler = sub {
+        my $req = $_dsl->request;
         _forward_home( $_dsl, $_[0] )
-            unless $_dsl->request->uri eq '/' && $_dsl->request->is_get;
+            if $req && ($req->uri ne '/' || !$req->is_get);
     };
 
     $message->reason($reason);
@@ -161,8 +168,9 @@ sub _error_handler($$$$)
             return _message_add( $_[0] )
                 if exists $options->{is_fatal} && !$options->{is_fatal};
 
+            my $req = $_dsl->request;
             return  _forward_home( $_dsl, $_[0] )
-                if $_dsl->request->uri ne '/' || !$_dsl->request->is_get;
+                if $req && ($req->uri ne '/' || !$req->is_get);
 
             return;
        }
