@@ -8,7 +8,7 @@ use strict;
 
 package Log::Report;
 use vars '$VERSION';
-$VERSION = '1.08';
+$VERSION = '1.09';
 
 use base 'Exporter';
 
@@ -63,9 +63,15 @@ sub report($@)
     my $reason = shift;
     my $stop = exists $opts->{is_fatal} ? $opts->{is_fatal} : is_fatal $reason;
 
-    my $try  = $nested_tries[-1];
-    my @disp = defined $try && $stop ? () : @{$reporter->{needs}{$reason}||[]};
-    push @disp, $try if defined $try && $try->needs($reason);
+    my @disp;
+    if(defined(my $try = $nested_tries[-1]))
+    {   push @disp, @{$reporter->{needs}{$reason}||[]}
+            unless $stop || $try->hides($reason);
+        push @disp, $try if $try->needs($reason);
+    }
+    else
+    {   @disp = @{$reporter->{needs}{$reason} || []};
+    }
 
     # return when no-one needs it: skip unused trace() fast!
     @disp || $stop or return;
@@ -148,8 +154,11 @@ sub report($@)
 }
 
 
+my %disp_actions = map +($_ => 1)
+ , qw/close find list disable enable mode needs filter active-try/;
+
 sub dispatcher($@)
-{   if($_[0] !~ m/^(?:close|find|list|disable|enable|mode|needs|filter)$/)
+{   if(! $disp_actions{$_[0]})
     {   my ($type, $name) = (shift, shift);
 
         # old dispatcher with same name will be closed in DESTROY
@@ -187,6 +196,9 @@ sub dispatcher($@)
         push @{$reporter->{filters}}, [ $code, \%names ];
         return ();
     }
+    if($command eq 'active-try')
+    {   return $nested_tries[-1];
+    }
 
     my $mode     = $command eq 'mode' ? shift : undef;
 
