@@ -7,7 +7,7 @@ use strict;
 
 package Log::Report::Dispatcher::Try;
 use vars '$VERSION';
-$VERSION = '1.08';
+$VERSION = '1.09';
 
 use base 'Log::Report::Dispatcher';
 
@@ -27,6 +27,14 @@ sub init($)
     defined $self->SUPER::init($args) or return;
     $self->{exceptions} = delete $args->{exceptions} || [];
     $self->{died}       = delete $args->{died};
+
+    if(my $h = $args->{hide})
+    {   my @h = ref $h eq 'ARRAY' ? @$h : defined $h ? $h : ();
+        $self->{hides}
+           = @h==0 ? undef
+           : @h==1 && $h[0] eq 'ALL' ? {} # empty HASH = ALL
+           :    +{ map +($_ => 1), @h };
+    }
     $self;
 }
 
@@ -47,6 +55,12 @@ sub died(;$)
 
 sub exceptions() { @{shift->{exceptions}} }
 
+
+sub hides($)
+{   my $h = shift->{hides} or return 0;
+    keys %$h ? $h->{(shift)} : 1;
+}
+
 #-----------------
 
 sub log($$$$)
@@ -58,17 +72,16 @@ sub log($$$$)
     $opts->{location} ||= '';
 
     my $e = Log::Report::Exception->new
-     ( reason      => $reason
-     , report_opts => $opts
-     , message     => $message
-     );
-
-    my $is_fatal = exists $opts->{is_fatal} ? $opts->{is_fatal} : $e->isFatal;
+      ( reason      => $reason
+      , report_opts => $opts
+      , message     => $message
+      );
 
     push @{$self->{exceptions}}, $e;
 
-    # later changed into nice message
-    $self->{died} ||= $opts->{is_fatal};
+    $self->{died} ||=
+        exists $opts->{is_fatal} ? $opts->{is_fatal} : $e->isFatal;
+
     $self;
 }
 
